import React, { createContext, useCallback, useEffect, useMemo, useState, } from 'react';
import AsyncStorage from '@react-native-async-storage/async-storage';
const RANDOM_KEY = '@react-native-use-persisted-state';
export const PersistedStateContext = createContext({});
const PersistedStateProvider = ({ children }) => {
    const [loading, setLoading] = useState(true);
    const [storage, setStorage] = useState({});
    useEffect(() => {
        // First init
        (async () => {
            const state = await AsyncStorage.getItem(RANDOM_KEY);
            if (state) {
                setStorage(JSON.parse(state));
            }
            setLoading(false);
        })();
    }, []);
    const setState = useCallback((key, state) => setStorage((prev) => {
        const newState = {
            ...prev,
            [key]: state,
        };
        // Storage state migrate to local storage
        setImmediate(() => AsyncStorage.setItem(RANDOM_KEY, JSON.stringify(newState)));
        return newState;
    }), []);
    const clearState = useCallback((key) => setStorage((prev) => {
        const newState = { ...prev };
        delete newState[key];
        // Storage state migrate to local storage
        setImmediate(() => AsyncStorage.setItem(RANDOM_KEY, JSON.stringify(newState)));
        return newState;
    }), []);
    const state = useMemo(() => ({
        storage,
        setState: setState,
        clearState: clearState,
    }), [storage, setState, clearState]);
    return (React.createElement(PersistedStateContext.Provider, { value: state }, loading ? null : children));
};
export default PersistedStateProvider;
